@@ -1,7 +1,7 @@
 __all__ = ["color", "parser", "load", "scroll, clear"]
 
 import bd103.color
-from bd103.color import print, paint
+from bd103.color import cprint, paint
 from bd103.parser import grid, space
 from bd103.load import load, loadbar
 from bd103.scroll import scroll
